"use strict";
const plugin_1 = require("./plugin");
const logger_1 = require("./logger");
const settings_1 = require("./settings");
const mockRequire = require("mock-require");
function isValidTypeScriptVersion(typescript) {
    const servicesVersion = typescript.servicesVersion;
    const [major, minor] = servicesVersion.split('.');
    return (+major === 0 && +minor >= 8);
}
module.exports = function init({ typescript }) {
    const configManager = new settings_1.ConfigurationManager(typescript);
    let logger;
    // Make sure TS Lint imports the correct version of TS
    mockRequire('typescript', typescript);
    return {
        create(info) {
            logger = logger_1.Logger.forPlugin(info);
            logger.info('Create');
            configManager.setProject(info.project, logger);
            configManager.updateFromPluginConfig(info.config);
            if (!isValidTypeScriptVersion(typescript)) {
                logger.info('Invalid typescript version detected. The TSLint plugin requires a version of TS with a services version between 0.8 and 1.0');
                return info.languageService;
            }
            return new plugin_1.TSLintPlugin(typescript, logger, info.project, configManager)
                .decorate(info.languageService);
        },
        onConfigurationChanged(config) {
            if (logger) {
                logger.info('onConfigurationChanged');
            }
            configManager.updateFromPluginConfig(config);
        },
    };
};
//# sourceMappingURL=index.js.map